@@ -146,6 +146,7 @@ class Cadence(cCadenceCore.CadenceCore):
         self.deltaMaxPriBump = priorities.get("deltaMaxPriBump", 10)
         self.deltaNomBump = priorities.get("deltaNomBump", 4)
         self.overDeltaMaxBump = priorities.get("overDeltaMaxBump", 100)
+        self.base_priority = priorities.get("base_priority", 50)
 
         return
 
@@ -208,13 +209,13 @@ class Cadence(cCadenceCore.CadenceCore):
     def skybrightness_check(self, epoch_idx, skybrightness_next):
         """check lunation for mjd_past against lunation_next"""
         down_weight = False
-        if(epoch_idx >= self.nepochs):
-            if self.skybrightness[-1] > 0.4:
-                if skybrightness_next < 0.4:
-                    down_weight = True
-            return skybrightness_next <= self.skybrightness[-1], down_weight
-        if self.skybrightness[epoch_idx] > 0.4:
-            if skybrightness_next < 0.4:
+        # if(epoch_idx >= self.nepochs):
+        #     if self.skybrightness[-1] > 0.35:
+        #         if skybrightness_next < 0.35:
+        #             down_weight = True
+        #     return skybrightness_next <= self.skybrightness[-1], down_weight
+        if self.skybrightness[epoch_idx] > 0.35:
+            if skybrightness_next < 0.35:
                 down_weight = True
         return skybrightness_next <= self.skybrightness[epoch_idx], down_weight
 
@@ -243,7 +244,7 @@ class Cadence(cCadenceCore.CadenceCore):
             print("done!")
             return(False, 0)
         else:
-            base_priority = 0
+            base_priority = self.base_priority
 
         ok_skybrightness, down_weight = self.skybrightness_check(epoch_idx,
                                                                  skybrightness_next)
@@ -274,11 +275,11 @@ class Cadence(cCadenceCore.CadenceCore):
         #     print("delta {} dhi {} dlo {} curr {:.2f}".format(dnom, dhi, dlo, float(delta_curr)), self.name)
         # 1/sqrt(x) priority; at 1 day +100, at 10 days +30, at 30 days +18
         remain_priority = self.deltaMaxPriBump * np.clip(10/np.sqrt(np.abs(dhi - delta_curr)),
-                                       a_min=None, a_max=10)
+                                                         a_min=None, a_max=10)
         nom_priority = self.deltaNomBump * np.clip(10/np.sqrt(np.abs(dnom - delta_curr)),
-                                   a_min=None, a_max=10)
+                                                   a_min=None, a_max=10)
         priority = base_priority + remain_priority + nom_priority
-        if delta_curr <= dhi:
+        if delta_curr >= dhi:
             priority += self.overDeltaMaxBump
         # if ignoreMax:
         #     return(ok_skybrightness & (delta_curr >= dlo), priority)
@@ -480,14 +481,19 @@ class CadenceList(object, metaclass=CadenceListSingleton):
         ok : bool
             True if these exposures under cadence #2 satisfy cadence #1
         """
+
+        cadence_two = self.cadences[two]
+        cadence_one = self.cadences[one]
+
+        # Are there fewer exposures than needed total?
+        if(len(iexp) < cadence_one.nexp_total):
+            return False
+
         # Are there any ways cadence one fits into cadence two?
         ok, epochs_list = self.cadence_consistency(one, two)
         if(not ok):
             return False
 
-        cadence_two = self.cadences[two]
-        cadence_one = self.cadences[one]
-
         # Now count how many exposures there are at each epoch for this
         # array of iexp
         epochs_two_got, nexps_got = np.unique(cadence_two.epochs[iexp],
@@ -495,8 +501,18 @@ class CadenceList(object, metaclass=CadenceListSingleton):
         ngot = np.zeros(cadence_two.nepochs, dtype=np.int32)
         ngot[epochs_two_got] = nexps_got
 
-        # Check each solution and see if the current assignment satisfies
+        # First check the obvious and most common case, which is
+        # that the actual epochs assigned are exactly what is needed
+        epochs_two = [int(x) for x in cadence_two.epochs[iexp]]
+        if(epochs_two in epochs_list):
+            nneed = np.zeros(cadence_two.nepochs, dtype=np.int32)
+            for epoch_one, epoch_two in enumerate(epochs_two):
+                nneed[epoch_two] = nneed[epoch_two] + cadence_one.nexp[epoch_one]
+            nbad = (ngot < nneed).sum()
+            if(nbad == 0):
+                return True
 
+        # Check each solution and see if the current assignment satisfies
         nneed = np.zeros(cadence_two.nepochs, dtype=np.int32)
         for epochs_two in epochs_list:
 
@@ -510,7 +526,7 @@ class CadenceList(object, metaclass=CadenceListSingleton):
                     bad = True
                     break
 
-            # For each exposure in the solution, are there enough exposures?
+            # For each epoch in the solution, are there enough exposures?
             if(not bad):
                 nbad = (ngot < nneed).sum()
                 if(nbad == 0):
@@ -884,4 +900,4 @@ class CadenceList(object, metaclass=CadenceListSingleton):
                              max_airmass=max_airmass,
                              obsmode_pk=np.array(cadence['obsmode_pk']),
                              label_root=str(cadence['label_root'].strip()),
-                             label_version=str(cadence['label_root'].strip()))
+                             label_version=str(cadence['label_version'].strip()))
